@@ -18,26 +18,21 @@
 #include "askdialog.h"
 #include "loadimage.h"
 #include "error.h"
-#include "permissions.h"
 #include "compressdlg.h"
 #include "unzip.h"
 #include "about.h"
 #include "home.h"
-#include "options.h"
 #include "selecticon.h"
+#include "filedelegate.h"
 #include "hildon-mime.h"
 #include "sys/vfs.h"
 
-#include <QItemDelegate>
-#include <QStandardItemModel>
-#include <QPainter>
-
 //#include "sharingdialog/sharing-dialog.h"
 
-
 #include "dbus-1.0/dbus/dbus.h"
 #include "libosso.h"
 
+
 int SymPressed;
 int ShPressed;
 int StartThread;
@@ -50,91 +45,9 @@ QFileSystemWatcher * watcher;
 int multi = 1;
 int ordenFile;
 QString color1, color2;
+QMenu *contextMenu;
 
 
-class PluginDelegate : public QAbstractItemDelegate {
-public:
-  PluginDelegate(QObject *parent=0) : QAbstractItemDelegate(parent){}
-  void paint ( QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index ) const
-  {
-      QFontMetrics fm = option.fontMetrics;
-
-      QString name = index.data(Qt::StatusTipRole).toString();
-      QString desc = index.data(Qt::UserRole+1).toString();
-
-      painter->save();
-      QRect r = option.rect;
-
-      if(option.state & QStyle::State_Selected){
-          QPixmap is1 = QPixmap("/etc/hildon/theme/images/TouchListBackgroundPressed.png");
-          painter->drawTiledPixmap(r,is1);
-      } else {
-          QPixmap is1 = QPixmap("/etc/hildon/theme/images/TouchListBackgroundNormal.png" );
-          painter->drawTiledPixmap(r,is1);
-      }
-
-      int space = 10;
-      if ( multi == 1 )
-      {
-          QPixmap choff = QPixmap("/etc/hildon/theme/images/CheckButtonUnchecked.png" );
-          QPixmap chon = QPixmap("/etc/hildon/theme/images/CheckButtonChecked.png" );
-          int xi = index.data(Qt::UserRole+3).toInt();
-          if ( xi == 1 )
-              painter->drawPixmap( r.left()+6, r.top()+16, 38, 38, chon );
-          else
-              painter->drawPixmap( r.left()+6, r.top()+16, 38, 38, choff );
-          space = 58;
-      }
-
-      QPixmap icon = QPixmap(index.data(Qt::UserRole+2).toString());
-      painter->drawPixmap( r.left()+space, r.top()+11, 48, 48, icon );
-
-      /*if ( index.data(Qt::UserRole+5).toString() != "" )
-      {
-          icon = QPixmap(index.data(Qt::UserRole+5).toString());
-          painter->drawPixmap( r.left()+space+10, r.top()+11+18, 28, 28, icon );
-      }*/
-
-      if ( index.data(Qt::UserRole+4).toString() != "" )
-          painter->drawImage(r.left()+space, r.top()+11, QImage(index.data(Qt::UserRole+4).toString()));
-
-      QColor base = QColor(color1);
-      painter->setPen(base);
-
-      r = option.rect;
-      r.setRight( r.right()-4 );
-      QFont f = painter->font();
-      f.setBold(false);
-      painter->setFont(f);
-
-      name = fm.elidedText(name, Qt::ElideRight, r.width()-56-space);
-      //desc = fm.elidedText(desc, Qt::ElideRight, r.width()-64-space);
-
-      if ( desc == "" )
-          painter->drawText(r.left()+54+space, r.top()+1, r.width()-12, r.height(), Qt::AlignVCenter|Qt::AlignLeft, name, &r);
-      else
-          painter->drawText(r.left()+54+space, r.top()+4, r.width()-12, r.height()-8, Qt::AlignTop|Qt::AlignLeft, name, &r);
-      f.setBold(false);
-      painter->setFont(f);
-
-
-      base = QColor(color2);
-      if ( desc == "brokenlink" ) { desc = tr("Broken Symlink"); painter->setPen(Qt::red); }
-      else painter->setPen(base);
-      f.setPointSize( f.pointSize()-4 );
-      painter->setFont(f);
-      r = option.rect;
-      if ( desc != "" ) painter->drawText(r.left()+54+space, r.top(), r.width()-10, r.height()-8, Qt::AlignBottom|Qt::AlignLeft, desc, &r);
-
-      painter->restore();
-
-  }
-  QSize sizeHint ( const QStyleOptionViewItem & option, const QModelIndex & index ) const
-  {
-      return QSize(5, 70);
-  }
-};
-
 
 MainWindow::MainWindow(QWidget *parent, QString openfolder) :
     QMainWindow(parent),
@@ -351,7 +264,7 @@ void MainWindow::CargarBrowser(QString directorio)
         agregarArchivo(list.at(i).absoluteFilePath());
     }
 
-    PluginDelegate *pluginDelegate = new PluginDelegate(this);
+    FileDelegate *pluginDelegate = new FileDelegate(this,multi,color1,color2);
     ui->listWidget->setItemDelegate(pluginDelegate);
 
     if ( ui->listWidget->count() > 0 ) {
@@ -842,76 +755,7 @@ void MainWindow::on_listWidget_customContextMenuRequested(QPoint pos)
     if ( ui->listWidget->count() == 0 ) return;
     if ( ui->listWidget->selectedItems().count() == 0 ) return;
 
-    /*QStringList list1;
-    if ( multi == 0 )
-    {
-        QString clip = sPath + "/" + ui->listWidget->currentItem()->statusTip();
-        list1.append(clip);
-    }
-    else
-    {
-        for (int i=0; i < ui->listWidget->count(); ++i)
-        {
-            if ( ui->listWidget->item(i)->checkState() == Qt::Checked )
-            {
-                QString clip = sPath + "/" + ui->listWidget->item(i)->statusTip();
-                list1.append(clip);
-            }
-        }
-    }
-
-    Options* ow = new Options(this, list1);
-    ow->exec();*/
-
-
-    int seleccionados=0;
-    QString item = sPath + "/" + ui->listWidget->currentItem()->statusTip();
-
-    if ( multi == 1 )
-    {
-        for (int mi=0; mi < ui->listWidget->count(); ++mi)
-        {
-            if ( ui->listWidget->item(mi)->checkState()==Qt::Checked ) seleccionados=seleccionados+1;
-        }
-        if (seleccionados==0) return;
-        if (seleccionados>=1 && ui->listWidget->currentItem()->checkState()==Qt::Unchecked ) return;
-    }
-
-
-    QMenu *contextMenu = new QMenu(this);
-    contextMenu->addAction(ic1, tr("Copy"), this, SLOT(addToClipboard()));
-
-    if ( (multi==0) || (multi==1 && seleccionados==1 && ui->listWidget->currentItem()->checkState()==Qt::Checked ) )
-        contextMenu->addAction(ic1, tr("Rename"), this, SLOT(renameSel()));
-
-    contextMenu->addAction(ic1, tr("Delete"), this, SLOT(removeSel()));
-
-    if ( ( multi==1 && seleccionados==1 && ui->listWidget->currentItem()->checkState()==Qt::Checked && QFileInfo(item).isFile() ) || ( multi==0 && QFileInfo(item).isFile() ) )
-    {
-        contextMenu->addAction(ic1, tr("Edit"), this, SLOT(editSel()));
-    }
-
-    if ( ( multi==1 && seleccionados==1 && ui->listWidget->currentItem()->checkState()==Qt::Checked && QFileInfo(item).isDir() ) ||  ( multi==0 && QFileInfo(item).isDir() ) )
-    {
-        contextMenu->addSeparator();
-        contextMenu->addAction(ic1, tr("Change icon"), this, SLOT(changeIcon()));
-    }
-    contextMenu->addAction(ic1, tr("Compress"), this, SLOT(compressSel()));
-
-    if ( ( multi==1 && seleccionados>0 ) ||  ( multi==0 && QFileInfo(item).isFile() ) )
-    {
-        contextMenu->addSeparator();
-        contextMenu->addAction(ic1, tr("Share"), this, SLOT(shareBT()));
-    }
-
-    /*if ( (multi==0) || (multi==1 && ui->listWidget->selectedItems().count()==1) )
-    {
-        contextMenu->addSeparator();
-        contextMenu->addAction(ic1, tr("Permissions"), this, SLOT(permissionSel()));
-    }*/
-
     contextMenu->exec(mapToGlobal(pos));
-
 }
 
 void MainWindow::changeIcon()
@@ -961,9 +805,9 @@ void MainWindow::compressSel()
 
 void MainWindow::permissionSel()
 {
-    QString file = sPath + "/" + ui->listWidget->currentItem()->statusTip();
-    Permissions* cw = new Permissions(this,file);
-    cw->exec();
+    //QString file = sPath + "/" + ui->listWidget->currentItem()->statusTip();
+    //Permissions* cw = new Permissions(this,file);
+    //cw->exec();
 
 }
 
@@ -1688,3 +1532,54 @@ void MainWindow::on_h_full_clicked()
     else
         this->setWindowState(Qt::WindowFullScreen);
 }
+
+void MainWindow::on_listWidget_itemSelectionChanged()
+{
+
+    int seleccionados=0;
+    QString item = sPath + "/" + ui->listWidget->currentItem()->statusTip();
+
+    if ( multi == 1 )
+    {
+        for (int mi=0; mi < ui->listWidget->count(); ++mi)
+        {
+            if ( ui->listWidget->item(mi)->checkState()==Qt::Checked ) seleccionados=seleccionados+1;
+        }
+        if (seleccionados==0) return;
+        if (seleccionados>=1 && ui->listWidget->currentItem()->checkState()==Qt::Unchecked ) return;
+    }
+
+    contextMenu = new QMenu(this);
+    contextMenu->addAction(ic1, tr("Copy"), this, SLOT(addToClipboard()));
+
+    if ( (multi==0) || (multi==1 && seleccionados==1 && ui->listWidget->currentItem()->checkState()==Qt::Checked ) )
+        contextMenu->addAction(ic1, tr("Rename"), this, SLOT(renameSel()));
+
+    contextMenu->addAction(ic1, tr("Delete"), this, SLOT(removeSel()));
+
+    if ( ( multi==1 && seleccionados==1 && ui->listWidget->currentItem()->checkState()==Qt::Checked && QFileInfo(item).isFile() ) || ( multi==0 && QFileInfo(item).isFile() ) )
+    {
+        contextMenu->addAction(ic1, tr("Edit"), this, SLOT(editSel()));
+    }
+
+    if ( ( multi==1 && seleccionados==1 && ui->listWidget->currentItem()->checkState()==Qt::Checked && QFileInfo(item).isDir() ) ||  ( multi==0 && QFileInfo(item).isDir() ) )
+    {
+        contextMenu->addSeparator();
+        contextMenu->addAction(ic1, tr("Change icon"), this, SLOT(changeIcon()));
+    }
+    contextMenu->addAction(ic1, tr("Compress"), this, SLOT(compressSel()));
+
+    if ( ( multi==1 && seleccionados>0 ) ||  ( multi==0 && QFileInfo(item).isFile() ) )
+    {
+        contextMenu->addSeparator();
+        contextMenu->addAction(ic1, tr("Share"), this, SLOT(shareBT()));
+    }
+
+    /*if ( (multi==0) || (multi==1 && ui->listWidget->selectedItems().count()==1) )
+    {
+        contextMenu->addSeparator();
+        contextMenu->addAction(ic1, tr("Permissions"), this, SLOT(permissionSel()));
+    }*/
+
+
+}
